MergeDataStrategy enum

Strategy to merge data from multiple providers

  • allAtOne - Emit a "loading state" without data until all providers have data. Then emit a "data state" with all providers data
  • oneByOne - A "loading state" is emitted along with the data of each provider until all providers have data. Then emit a "data state" with all providers data.
Inheritance
Available extensions

Values

allAtOne → const MergeDataStrategy
oneByOne → const MergeDataStrategy

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MergeDataStrategy>
A constant List of the values in this enum, in order of their declaration.