SinglePageState<T> class

Inheritance

Constructors

SinglePageState(Iterable<T> items)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
nbHits int?
finalinherited
pItems Iterable<T>
The items of the current page
finalinherited
pLast int?
The last page index
finalinherited
pLimit int
Optional parameter to specify the limit of items per page.
finalinherited
pPage int
The current page index
finalinherited
pPath String?
The path of the API request or anything else that will be used in logs
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited